@@ -78,6 +78,7 @@ class Actions(str, Enum):
     GET_WAN_INFO: str = f"{ROOT}/router/GetWANStatus3"
     GET_WPS_SERVER_SETTINGS: str = f"{ROOT}/wirelessap/GetWPSServerSettings"
     REBOOT: str = f"{ROOT}/core/Reboot"
+    SET_DEVICE_PROPERTY: str = f"{ROOT}/devicelist/SetDeviceProperties"
     SET_GUEST_NETWORK: str = f"{ROOT}/guestnetwork/SetGuestRadioSettings2"
     SET_PARENTAL_CONTROL_INFO: str = (
         f"{ROOT}/parentalcontrol/SetParentalControlSettings"
@@ -265,6 +266,12 @@ class Response:
                     err = MeshCannotDeleteDevice
                 elif resp.get(self.RESULT_KEY) == "ErrorDeviceNotInMasterMode":
                     err = MeshNodeNotPrimary
+                elif resp.get(self.RESULT_KEY) == "ErrorInvalidWANSchedule":
+                    err = MeshInvalidInput("Invalid WAN Schedule")
+                elif resp.get(self.RESULT_KEY) == "ErrorRulesOverlap":
+                    err = MeshInvalidInput("Rules Overlap")
+                elif resp.get(self.RESULT_KEY) == "ErrorUnknownDevice":
+                    err = MeshInvalidInput("Unknown Device")
                 elif resp.get(self.RESULT_KEY).startswith("_"):
                     err = MeshInvalidInput(
                         f"{resp.get(self.RESULT_KEY)}: '{self.action}'"
